@@ -93,6 +93,9 @@ cupsdAddEvent(
   * caches...
   */
 
+  if (job && !dest)
+    dest = cupsdFindPrinter(job->dest);
+
   for (temp = NULL, sub = (cupsd_subscription_t *)cupsArrayFirst(Subscriptions);
        sub;
        sub = (cupsd_subscription_t *)cupsArrayNext(Subscriptions))
@@ -119,11 +122,7 @@ cupsdAddEvent(
       temp->time  = time(NULL);
       temp->attrs = ippNew();
       temp->job	  = job;
-
-      if (dest)
-	temp->dest = dest;
-      else if (job)
-	temp->dest = dest = cupsdFindPrinter(job->dest);
+      temp->dest  = dest;
 
      /*
       * Add common event notification attributes...
