@@ -1,7 +1,7 @@
 /*
  * Configuration file for CUPS and Xcode.
  *
- * Copyright © 2021-2024 by OpenPrinting
+ * Copyright © 2021-2025 by OpenPrinting
  * Copyright © 2007-2019 by Apple Inc.
  * Copyright © 1997-2007 by Easy Software Products.
  *
@@ -19,8 +19,8 @@
  * Version of software...
  */
 
-#define CUPS_SVERSION "CUPS v2.4.10"
-#define CUPS_MINIMAL "CUPS/2.4.10"
+#define CUPS_SVERSION "CUPS v2.4.12"
+#define CUPS_MINIMAL "CUPS/2.4.12"
 
 
 /*
@@ -398,6 +398,13 @@
 #define HAVE_TM_GMTOFF 1
 
 
+/*
+ * Do we have the timegm function?
+ */
+
+#define HAVE_TIMEGM 1
+
+
 /*
  * Do we have rresvport_af()?
  */
